Changelog
=========


v0.1.0 (30th December, 2024)
-----------------------------

Initial release with support for rust binary parsing to:

* Get packages and dependencies information from a rust binary
* Get parsed list of demangled and cleaned symbols from a rust binary
* A scancode-toolkit plugin for colelcting rust symbols with the option --rust-symbol
* A scancode-toolkit DatafileHandler to integrate getting package data from a rust binary
